@@ -348,7 +348,11 @@ bool wxStfApp::OnInit(void)
 int wxStfApp::OnExit()
 {
 #if wxUSE_CONFIG
+#if (wxCHECK_VERSION(3, 0, 0))
+    GetDocManager()->FileHistorySave(*wxConfigBase::Get());
+#else
     GetDocManager()->FileHistorySave(*wxConfig::Get());
+#endif
 #endif // wxUSE_CONFIG
 
     delete GetDocManager();
